@@ -1,6 +1,7 @@
 
 test_that("fusions_filter", {
-  demo_file <- system.file("extdata", "demo/proteinpaint/fusions2pp_fusioncatcher.txt", package = "ngstk")
+  demo_file <- system.file("extdata", "demo/proteinpaint/fusions2pp_fusioncatcher.txt", 
+    package = "ngstk")
   input_data <- read.table(demo_file, sep = "\t", header = TRUE, stringsAsFactors = FALSE)
   
   mhandler_extra_params = list(gene_5 = 1, gene_3 = 2, any_gene = "TCF3", fusions_any_match_flag = TRUE)
@@ -12,10 +13,12 @@ test_that("fusions_filter", {
   mhandler_extra_params = list(gene_5 = 1, left_gene = "GYPA", fusions_left_match_flag = TRUE)
   result_3 <- fusions_filter(input_data, mhandler_extra_params = mhandler_extra_params)
   
-  mhandler_extra_params = list(gene_5 = 1, gene_3 = 2, left_gene = "GYPE", right_gene = "GYPA", fusions_full_match_flag = TRUE)
+  mhandler_extra_params = list(gene_5 = 1, gene_3 = 2, left_gene = "GYPE", right_gene = "GYPA", 
+    fusions_full_match_flag = TRUE)
   result_4 <- fusions_filter(input_data, mhandler_extra_params = mhandler_extra_params)
   
-  mhandler_extra_params = list(gene_5 = 1, gene_3 = 2, left_gene = "GYPE", right_gene = "GYPA", fusions_anyfull_match_flag = TRUE)
+  mhandler_extra_params = list(gene_5 = 1, gene_3 = 2, left_gene = "GYPE", right_gene = "GYPA", 
+    fusions_anyfull_match_flag = TRUE)
   result_5 <- fusions_filter(input_data, mhandler_extra_params = mhandler_extra_params)
   
   expect_that(nrow(result_1), equals(5))
